# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .application import *
from .aws_credentials import *
from .cluster import *
from .container import *
from .container_registry import *
from .database import *
from .deployment import *
from .deployment_stage import *
from .environment import *
from .get_application import *
from .get_aws_credentials import *
from .get_cluster import *
from .get_container import *
from .get_container_registry import *
from .get_database import *
from .get_deployment import *
from .get_deployment_stage import *
from .get_environment import *
from .get_git_token import *
from .get_helm import *
from .get_helm_repository import *
from .get_job import *
from .get_organization import *
from .get_project import *
from .get_scaleway_credentials import *
from .git_token import *
from .helm import *
from .helm_repository import *
from .job import *
from .organization import *
from .project import *
from .provider import *
from .scaleway_credentials import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import ediri_qovery.config as __config
    config = __config
else:
    config = _utilities.lazy_import('ediri_qovery.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "qovery",
  "mod": "index/application",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/application:Application": "Application"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/awsCredentials",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/awsCredentials:AwsCredentials": "AwsCredentials"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/cluster",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/container",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/container:Container": "Container"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/containerRegistry",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/containerRegistry:ContainerRegistry": "ContainerRegistry"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/database",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/database:Database": "Database"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/deployment",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/deploymentStage",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/deploymentStage:DeploymentStage": "DeploymentStage"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/environment",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/gitToken",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/gitToken:GitToken": "GitToken"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/helm",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/helm:Helm": "Helm"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/helmRepository",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/helmRepository:HelmRepository": "HelmRepository"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/job",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/job:Job": "Job"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/organization",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/project",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/project:Project": "Project"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/scalewayCredentials",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/scalewayCredentials:ScalewayCredentials": "ScalewayCredentials"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "qovery",
  "token": "pulumi:providers:qovery",
  "fqn": "ediri_qovery",
  "class": "Provider"
 }
]
"""
)
