# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('qovery')


class _ExportableConfig(types.ModuleType):
    @property
    def token(self) -> Optional[str]:
        """
        The Qovery API Token to use. This can also be specified with the `QOVERY_API_TOKEN` shell environment variable.
        """
        return __config__.get('token') or _utilities.get_env('QOVERY_API_TOKEN')

