# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HelmRepositoryArgs', 'HelmRepository']

@pulumi.input_type
class HelmRepositoryArgs:
    def __init__(__self__, *,
                 kind: pulumi.Input[str],
                 organization_id: pulumi.Input[str],
                 skip_tls_verification: pulumi.Input[bool],
                 url: pulumi.Input[str],
                 config: Optional[pulumi.Input['HelmRepositoryConfigArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a HelmRepository resource.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        :param pulumi.Input['HelmRepositoryConfigArgs'] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] name: Name of the helm repository.
        """
        pulumi.set(__self__, "kind", kind)
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "skip_tls_verification", skip_tls_verification)
        pulumi.set(__self__, "url", url)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Input[str]:
        """
        Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
        `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: pulumi.Input[str]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Input[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="skipTlsVerification")
    def skip_tls_verification(self) -> pulumi.Input[bool]:
        """
        Bypass tls certificate verification when connecting to repository
        """
        return pulumi.get(self, "skip_tls_verification")

    @skip_tls_verification.setter
    def skip_tls_verification(self, value: pulumi.Input[bool]):
        pulumi.set(self, "skip_tls_verification", value)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[str]:
        """
        URL of the helm repository.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['HelmRepositoryConfigArgs']]:
        """
        Configuration needed to authenticate the helm repository.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['HelmRepositoryConfigArgs']]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the helm repository.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the helm repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _HelmRepositoryState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input['HelmRepositoryConfigArgs']] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kind: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 skip_tls_verification: Optional[pulumi.Input[bool]] = None,
                 url: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering HelmRepository resources.
        :param pulumi.Input['HelmRepositoryConfigArgs'] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] name: Name of the helm repository.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if skip_tls_verification is not None:
            pulumi.set(__self__, "skip_tls_verification", skip_tls_verification)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['HelmRepositoryConfigArgs']]:
        """
        Configuration needed to authenticate the helm repository.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['HelmRepositoryConfigArgs']]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the helm repository.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[str]]:
        """
        Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
        `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kind", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the helm repository.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="skipTlsVerification")
    def skip_tls_verification(self) -> Optional[pulumi.Input[bool]]:
        """
        Bypass tls certificate verification when connecting to repository
        """
        return pulumi.get(self, "skip_tls_verification")

    @skip_tls_verification.setter
    def skip_tls_verification(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "skip_tls_verification", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        URL of the helm repository.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)


class HelmRepository(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kind: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 skip_tls_verification: Optional[pulumi.Input[bool]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # HelmRepository (Resource)

        Provides a Qovery helm repository resource. This can be used to create and manage Qovery helm repository.

        ## Import

        ```sh
         $ pulumi import qovery:index/helmRepository:HelmRepository my_helm_repository "<organization_id>,<helm_repository_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] name: Name of the helm repository.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HelmRepositoryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # HelmRepository (Resource)

        Provides a Qovery helm repository resource. This can be used to create and manage Qovery helm repository.

        ## Import

        ```sh
         $ pulumi import qovery:index/helmRepository:HelmRepository my_helm_repository "<organization_id>,<helm_repository_id>"
        ```

        :param str resource_name: The name of the resource.
        :param HelmRepositoryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HelmRepositoryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kind: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 skip_tls_verification: Optional[pulumi.Input[bool]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HelmRepositoryArgs.__new__(HelmRepositoryArgs)

            __props__.__dict__["config"] = config
            __props__.__dict__["description"] = description
            if kind is None and not opts.urn:
                raise TypeError("Missing required property 'kind'")
            __props__.__dict__["kind"] = kind
            __props__.__dict__["name"] = name
            if organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'organization_id'")
            __props__.__dict__["organization_id"] = organization_id
            if skip_tls_verification is None and not opts.urn:
                raise TypeError("Missing required property 'skip_tls_verification'")
            __props__.__dict__["skip_tls_verification"] = skip_tls_verification
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
        super(HelmRepository, __self__).__init__(
            'qovery:index/helmRepository:HelmRepository',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']]] = None,
            description: Optional[pulumi.Input[str]] = None,
            kind: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            skip_tls_verification: Optional[pulumi.Input[bool]] = None,
            url: Optional[pulumi.Input[str]] = None) -> 'HelmRepository':
        """
        Get an existing HelmRepository resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['HelmRepositoryConfigArgs']] config: Configuration needed to authenticate the helm repository.
        :param pulumi.Input[str] description: Description of the helm repository.
        :param pulumi.Input[str] kind: Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
               `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        :param pulumi.Input[str] name: Name of the helm repository.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[bool] skip_tls_verification: Bypass tls certificate verification when connecting to repository
        :param pulumi.Input[str] url: URL of the helm repository.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HelmRepositoryState.__new__(_HelmRepositoryState)

        __props__.__dict__["config"] = config
        __props__.__dict__["description"] = description
        __props__.__dict__["kind"] = kind
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["skip_tls_verification"] = skip_tls_verification
        __props__.__dict__["url"] = url
        return HelmRepository(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output[Optional['outputs.HelmRepositoryConfig']]:
        """
        Configuration needed to authenticate the helm repository.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the helm repository.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def kind(self) -> pulumi.Output[str]:
        """
        Kind of the helm repository. - Can be: `HTTPS`, `OCI_DOCKER_HUB`, `OCI_DOCR`, `OCI_ECR`, `OCI_GENERIC_CR`,
        `OCI_GITHUB_CR`, `OCI_GITLAB_CR`, `OCI_PUBLIC_ECR`, `OCI_SCALEWAY_CR`.
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the helm repository.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="skipTlsVerification")
    def skip_tls_verification(self) -> pulumi.Output[bool]:
        """
        Bypass tls certificate verification when connecting to repository
        """
        return pulumi.get(self, "skip_tls_verification")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        URL of the helm repository.
        """
        return pulumi.get(self, "url")

