# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetScalewayCredentialsResult',
    'AwaitableGetScalewayCredentialsResult',
    'get_scaleway_credentials',
    'get_scaleway_credentials_output',
]

@pulumi.output_type
class GetScalewayCredentialsResult:
    """
    A collection of values returned by getScalewayCredentials.
    """
    def __init__(__self__, id=None, name=None, organization_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        return pulumi.get(self, "organization_id")


class AwaitableGetScalewayCredentialsResult(GetScalewayCredentialsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetScalewayCredentialsResult(
            id=self.id,
            name=self.name,
            organization_id=self.organization_id)


def get_scaleway_credentials(id: Optional[str] = None,
                             organization_id: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetScalewayCredentialsResult:
    """
    ## # ScalewayCredentials (Data Source)

    Use this data source to retrieve information about an existing Scaleway credentials.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['organizationId'] = organization_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getScalewayCredentials:getScalewayCredentials', __args__, opts=opts, typ=GetScalewayCredentialsResult).value

    return AwaitableGetScalewayCredentialsResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'))


@_utilities.lift_output_func(get_scaleway_credentials)
def get_scaleway_credentials_output(id: Optional[pulumi.Input[str]] = None,
                                    organization_id: Optional[pulumi.Input[str]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetScalewayCredentialsResult]:
    """
    ## # ScalewayCredentials (Data Source)

    Use this data source to retrieve information about an existing Scaleway credentials.
    """
    ...
